.. Swing documentation master file, created by
   sphinx-quickstart on Tue Feb 25 17:06:20 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Swing documentation
===================

The ``Swing`` class uses a mechanical approach to determine the trend of a stock along with breakout and reversal levels.

Python version: >= 3.8

No external dependencies are required.

Pandas and Mplfinance are optional requirements depending on your usage and requirement.

.. toctree::

   usage
   swing_algorithm
